@@ -23,7 +23,7 @@ import Data.Data
 import Data.Fixed (Fixed (MkFixed))
 import Data.Sequence qualified as Seq
 import Data.Text (Text, pack, unpack)
-import Data.Time
+import Data.Time hiding (Hours, Minutes, Seconds)
 import NumHask.Prelude
 import NumHask.Space.Range
 import NumHask.Space.Types
@@ -34,8 +34,9 @@ import NumHask.Space.Types
 -- >>> :set -XRebindableSyntax
 -- >>> import NumHask.Prelude
 -- >>> import NumHask.Space
+-- >>> import NumHask.Space.Time (TimeGrain(..))
 -- >>> import Data.Text (Text, pack)
--- >>> import Data.Time
+-- >>> import Data.Time hiding (Hours, Minutes, Seconds)
 
 -- | a step in time
 data TimeGrain
